##
##  consul-template.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_consul_template_base 0.29.2
%define       V_consul_template_snap 20220826

#   package information
Name:         consul-template
Summary:      Template Engine for Consul Discovery Service
URL:          https://github.com/hashicorp/consul-template
Vendor:       Hashicorp
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MPL
Version:      %{V_consul_template_base}.%{V_consul_template_snap}
Release:      20220826

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/consul/consul-template-%{V_consul_template_snap}.tar.xz
Source1:      rc.consul-template
Source2:      consul-template.conf
Source3:      example.tmpl
Source4:      example.sh

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, consul

%description
    This is a companion tool to Consul, a service discovery and
    configuration service. It polls Consul for configuration information
    and creates configuration files based on template files.

%track
    prog consul-template:release = {
        version   = %{V_consul_template_base}
        url       = https://github.com/hashicorp/consul-template/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog consul-template:snapshot = {
        version   = %{V_consul_template_snap}
        url       = http://download.openpkg.org/components/versioned/consul/
        regex     = consul-template-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n consul-template

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/hashicorp/consul-template
    go build -v -o bin/consul-template

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/consul-template \
        $RPM_BUILD_ROOT%{l_prefix}/var/consul-template/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/consul-template/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/consul-template/data

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/hashicorp/consul-template/bin/consul-template \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/consul-template

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.consul-template} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE consul-template.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/consul-template/

    #   install example
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE example.tmpl} $RPM_BUILD_ROOT%{l_prefix}/var/consul-template/data/
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE example.sh} $RPM_BUILD_ROOT%{l_prefix}/var/consul-template/data/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/consul-template/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/consul-template/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/consul-template/*/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} consul-template status 2>/dev/null`
    [ ".$consul_template_active" = .yes ] && %{l_rc} consul-template restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} consul-template stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/consul-template/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/consul-template/run/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/consul-template/data/* >/dev/null 2>&1 || true
    exit 0

